authenticate_tmc_server

Function authenticate_tmc_server 

pub async fn authenticate_tmc_server(
    request: &HttpRequest,
) -> Result<AuthorizationToken, ControllerError>
Checks the Authorization header against a secret from environment variables to verify the request originates from the TMC server.