pub async fn authenticate_tmc_server(
request: &HttpRequest,
) -> Result<AuthorizationToken, ControllerError>Expand description
Checks the Authorization header against a secret from environment variables to verify the request originates from the TMC server.