pub fn session_user_id(session: &Session) -> Option<Uuid>
The id of the user the session is signed in as, without checking the user still exists. For keying things like rate limits; use the AuthUser extractor to authenticate.
AuthUser